summaryrefslogtreecommitdiffstats
path: root/nixos/modules/services/video
diff options
context:
space:
mode:
authorDoron Behar <doron.behar@gmail.com>2023-04-11 18:02:48 +0300
committerDoron Behar <doron.behar@gmail.com>2023-04-12 12:23:44 +0300
commit504849a7bb581207756d5767d55213ee422281ce (patch)
tree64fa40ed97303b060bb57ee2783a0afaf0232ab7 /nixos/modules/services/video
parent121dfc185a23113173e653cd538f80ff9171f3c3 (diff)
rtsp-simple-server: rebrand as mediamtx
Diffstat (limited to 'nixos/modules/services/video')
-rw-r--r--nixos/modules/services/video/mediamtx.nix (renamed from nixos/modules/services/video/rtsp-simple-server.nix)32
1 files changed, 16 insertions, 16 deletions
diff --git a/nixos/modules/services/video/rtsp-simple-server.nix b/nixos/modules/services/video/mediamtx.nix
index 2dd62edab787..18a9e3d5fe30 100644
--- a/nixos/modules/services/video/rtsp-simple-server.nix
+++ b/nixos/modules/services/video/mediamtx.nix
@@ -3,19 +3,19 @@
with lib;
let
- cfg = config.services.rtsp-simple-server;
- package = pkgs.rtsp-simple-server;
+ cfg = config.services.mediamtx;
+ package = pkgs.mediamtx;
format = pkgs.formats.yaml {};
in
{
options = {
- services.rtsp-simple-server = {
- enable = mkEnableOption (lib.mdDoc "RTSP Simple Server");
+ services.mediamtx = {
+ enable = mkEnableOption (lib.mdDoc "MediaMTX");
settings = mkOption {
description = lib.mdDoc ''
- Settings for rtsp-simple-server.
- Read more at <https://github.com/aler9/rtsp-simple-server/blob/main/rtsp-simple-server.yml>
+ Settings for MediaMTX.
+ Read more at <https://github.com/aler9/mediamtx/blob/main/mediamtx.yml>
'';
type = format.type;
@@ -25,7 +25,7 @@ in
"stdout"
];
# we set this so when the user uses it, it just works (see LogsDirectory below). but it's not used by default.
- logFile = "/var/log/rtsp-simple-server/rtsp-simple-server.log";
+ logFile = "/var/log/mediamtx/mediamtx.log";
};
example = {
@@ -40,20 +40,20 @@ in
env = mkOption {
type = with types; attrsOf anything;
- description = lib.mdDoc "Extra environment variables for RTSP Simple Server";
+ description = lib.mdDoc "Extra environment variables for MediaMTX";
default = {};
example = {
- RTSP_CONFKEY = "mykey";
+ MTX_CONFKEY = "mykey";
};
};
};
};
config = mkIf (cfg.enable) {
- # NOTE: rtsp-simple-server watches this file and automatically reloads if it changes
- environment.etc."rtsp-simple-server.yaml".source = format.generate "rtsp-simple-server.yaml" cfg.settings;
+ # NOTE: mediamtx watches this file and automatically reloads if it changes
+ environment.etc."mediamtx.yaml".source = format.generate "mediamtx.yaml" cfg.settings;
- systemd.services.rtsp-simple-server = {
+ systemd.services.mediamtx = {
environment = cfg.env;
after = [ "network.target" ];
@@ -65,15 +65,15 @@ in
serviceConfig = {
DynamicUser = true;
- User = "rtsp-simple-server";
- Group = "rtsp-simple-server";
+ User = "mediamtx";
+ Group = "mediamtx";
- LogsDirectory = "rtsp-simple-server";
+ LogsDirectory = "mediamtx";
# user likely may want to stream cameras, can't hurt to add video group
SupplementaryGroups = "video";
- ExecStart = "${package}/bin/rtsp-simple-server /etc/rtsp-simple-server.yaml";
+ ExecStart = "${package}/bin/mediamtx /etc/mediamtx.yaml";
};
};
};